/*****************************************************************************
 *
 * File: Univ7_5.ddl
 * Version: 7.5.0
 * Date: 1/14/2022
 *
 *****************************************************************************
 * Copyright (c) 2016-2022, FieldComm Group, All Rights Reserved
 *****************************************************************************
 *
 * Description: This file contains the DDL based model of the HART7 Universal
 *      Command Specification.  There were significant changes in this model
 *      reflecting the increasing focus on the device variable. This resulted
 *      in a hierachal model that matches the one taught in the Writing Device
 *      Description Workshop and the Command Summary Specification.
 *
 * Source Specifications (These are revision numbers of the protocol specs which
 *                        may differ from the standard DD revision numbers.)
 *      Command Practice Command Specification      Rev.12.0
 *      Command Summary Specification               Rev.10.1
 *      Universal Command Specification             Rev.7.2
 *      Common Tables Specification                 Rev.25.0
 *
 *****************************************************************************
 */

/*****************************************************************************
 * The manufacturer line
 *****************************************************************************
 */
MANUFACTURER STANDARD, DEVICE_TYPE _UNIVERSAL, DEVICE_REVISION 7, DD_REVISION 5

/*****************************************************************************
 * Include Files
 *****************************************************************************
 */
#include "macros2.h"
#include "embedded_strings.h"
#include "methods.h"

/*****************************************************************************
 * Definitions (#define, typedef, enum)
 *****************************************************************************
 */

/*****************************************************************************
 * The following VARIABLEs (response_code, comm_status, and device_status)
 * are common to all HART commands.  These three also have magic significance
 * to DDL masters.  For example, response_code takes on the enumerations
 * defined in the command transaction in progress.
 *
 *****************************************************************************
 * Command Specific Response Codes are encoded in bits #6 - #0 of the
 * first byte of the Response Codes. These codes are 7-bit enumerated
 * values ranging from 0 to 127.  DDL masters must determine the actual
 * command specific enumerations based on the COMMMAND and RESPONSE_CODES
 * currently being communicated.
 *
 * All COMMAND REPLY declarations must include this VARIABLE as the first
 * parameter.  If in the actual slave communications response the high order
 * bit is set the master must update the value of the comm_status VARIABLE
 * when this happens the value of response_code VARIABLE is not defined.
 *
 * NOTE - Specific requirements for the definition and use of response codes
 *      are specified in " Command Response Code Specification"
 *****************************************************************************
 */

VARIABLE response_code
{
//Remove new dictionary references from legacy binary format
    LABEL response_code_temp;
//Remove new dictionary references from legacy binary format
    HELP response_code_help_temp;
    CLASS HART & DIAGNOSTIC;
    HANDLING READ;
    TYPE ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 0,  success_temp },                     /* These are the single defintion errors!!! */
//Remove new dictionary references from legacy binary format
        { 2,  invalid_selection_temp },           /* DDL masters must determine the actual  command */
//Remove new dictionary references from legacy binary format
        { 3,  Parameter_too_large_temp },         /* specific enumerations found in the COMMMAND */
//Remove new dictionary references from legacy binary format
        { 4,  Parameter_too_small_temp },         /* and RESPONSE_CODES currently being communicated. */
//Remove new dictionary references from legacy binary format
        { 5,  too_few_data_bytes_recieved_temp },
//Remove new dictionary references from legacy binary format
        { 6,  xmtr_specific_command_error_temp },
//Remove new dictionary references from legacy binary format
        { 7,  in_write_protect_mode_temp },
//Remove new dictionary references from legacy binary format
        { 16, access_restricted_temp } ,
//Remove new dictionary references from legacy binary format
        { 32, busy_temp },
//Remove new dictionary references from legacy binary format
        { 33, delayed_response_initiated_temp },
//Remove new dictionary references from legacy binary format
        { 34, delayed_response_running_temp },
//Remove new dictionary references from legacy binary format
        { 35, delayed_response_dead_temp },
//Remove new dictionary references from legacy binary format
        { 36, delayed_response_conflict_temp },
//Remove new dictionary references from legacy binary format
        { 64, Command_not_implemented_temp }
    }
}

/*****************************************************************************
 * This VARIABLE never actually is seen in a COMMAND declaration.  DDL masters
 * demultiplex the first byte in all slave responses to update either
 * response_code of comm_status
 *
 * If in the actual slave communications response the high order
 * bit is set the master must update the value of the comm_status VARIABLE
 * when this happens the value of response_code VARIABLE is not defined.
 *****************************************************************************
 */
VARIABLE comm_status
{
//Remove new dictionary references from legacy binary format
    LABEL communications_status_temp;
//Remove new dictionary references from legacy binary format
    HELP communications_status_help_temp;
    CLASS HART & DYNAMIC & DIAGNOSTIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 0x02, Buffer_Overflow_temp,              HARDWARE & CORRECTABLE },
//Remove new dictionary references from legacy binary format
        { 0x08, Longitudinal_Parity_Error_temp,    HARDWARE & CORRECTABLE },
//Remove new dictionary references from legacy binary format
        { 0x10, Framing_Error_temp,                HARDWARE & CORRECTABLE },
//Remove new dictionary references from legacy binary format
        { 0x20, Overrun_Error_temp,                HARDWARE & CORRECTABLE },
//Remove new dictionary references from legacy binary format
        { 0x40, Vertical_Parity_Error_temp,        HARDWARE & CORRECTABLE }
    }
}

/*****************************************************************************
 * request_preambles suggest how many pre-ambles a master should send a field
 * device.  preambles are a physical layer requirement and are used to train
 * the demodulator and the uart and seynchronize to the start of a message
 *
 * This value is usually 5.  this value must not be abused or utilized to
 * cover up file device software limitations.  large values returned in this
 * VARIABLE reduce communication throughput and must be avoided.
 *
 *****************************************************************************
 */
VARIABLE request_preambles
{
//Remove new dictionary references from legacy binary format
    LABEL request_preambles_temp;
//Remove new dictionary references from legacy binary format
    HELP request_preambles_help_temp;
    CLASS HART;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER;
}

/*****************************************************************************
 * universal_revision indicates the major revision of the protocol supported
 * by THE field device.  It also allows non-dd capable hosts to select the
 * Universal Commands that the field device supports.  the value returned by
 * the field device should be 6
 *
 * NOTE - Field Device Developers must support all specifications of a specifc
 * revision of the protocol as indicated by the "Hart Filed Communications
 * Protocol Specification" document.  A developer is not allowed to  pick
 * and choose features to support from differnt specification revisions.
 *
 *****************************************************************************
 */
VARIABLE universal_revision
{
//Remove new dictionary references from legacy binary format
    LABEL protocol_revision_temp;
//Remove new dictionary references from legacy binary format
    HELP protocol_revision_help_temp;
    CLASS HART;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER
    {
        MIN_VALUE 7;    //Helps for applications that do not support DEFAULT_VALUE
    }
    DEFAULT_VALUE 7;
}

/*****************************************************************************
 * This variable, along with the Manufacturer ID and Device Type  define a
 * unique set of commands.  In other words the HART Application Layer included
 * in this field device (universal common practice, and device specific command
 * and data set. This is a whole number that matches the revision level of the
 * device specification documentation required by the Protocol  the format of
 * this device specific document is found in HCF_LIT-18
 *
 *****************************************************************************
 */
VARIABLE transmitter_revision
{
//Remove new dictionary references from legacy binary format
    LABEL device_revision_temp;
//Remove new dictionary references from legacy binary format
    HELP device_revision_help_temp;
    CLASS HART;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER;
}

/*****************************************************************************
 * The device/transmitter revision indicates the command set supported by the
 * this variable is incremented everytime the firmware in the field device
 * changes (modifications to the firmware may not affect the commands or data
 * accessable via the HART application layer).
 *
 * This variable could potentially be utilized as a handle for recalling
 * Field Devices with a software discrepancy."
 *
 *****************************************************************************
 */
VARIABLE software_revision
{
//Remove new dictionary references from legacy binary format
    LABEL Software_Revision_temp;
//Remove new dictionary references from legacy binary format
    HELP software_revision_help_temp;
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER;
}

/*****************************************************************************
 * The hardware revision is utilized to track what ever level of modifications
 * are desired. However, minor changes in components values etc. should not
 * cause this value to be incremented.
 *
 * NOTE - please note that in many hardware / software configurations the
 * software can be removed from the hardware to be upgraded, moved, etc.. In
 * this situation the variable hardware_revision must not reside in the
 * software, but should be readable via from the actual hardware  itself.
 *
 *****************************************************************************
 */
VARIABLE hardware_revision
{
//Remove new dictionary references from legacy binary format
    LABEL Hardware_Revision_temp;
//Remove new dictionary references from legacy binary format
    HELP hardware_revision_help_temp;
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER;
}

/*****************************************************************************
 * This variable should be written into the Field Device in the manufacturing
 * process. Every device shipped must have a different value for this variable
 * This variable along with the manufacturer_id and device_type. indicate one
 * and only one unique device.  many host systems combine these three
 * variables to track the devices life cycle.
 *
 *****************************************************************************
 */
VARIABLE device_id
{
//Remove new dictionary references from legacy binary format
    LABEL Device_Identification_temp;
//Remove new dictionary references from legacy binary format
    HELP device_identification_help_temp;
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (3);
}

/*****************************************************************************
 * response preambles are set by command 59 and indicate the number of
 * preambles the master needs for is physical layer.  preambles are a physical
 * layer requirement and are used to train the demodulator and the uart
 * and seynchronize to the start of a message
 *
 * This value is usually 5.  this value must not vary from message to message,
 * it must not be abused or utilized to cover up file device software
 * limitations.  large values returned in this VARIABLE reduce communication
 * throughput and must be avoided.
 *
 *****************************************************************************
 */
VARIABLE response_preambles
{
//Remove new dictionary references from legacy binary format
    LABEL response_preambles_temp;
//Remove new dictionary references from legacy binary format
    HELP response_preambles_help_temp;
    CLASS HART;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER
    {
        MIN_VALUE  5;
        MAX_VALUE  20;
    }
}

/*****************************************************************************
 * This variable indicates the last Device Variable code that a host application
 * should expect to be found in the field device (other than the Standard
 * Device Variables like Battery Life, Percent of Range, Loop current,
 * PV, SV, TV, and QV).
 *****************************************************************************
 */
VARIABLE max_num_device_variables
{
//Remove new dictionary references from legacy binary format
    LABEL maximum_device_variables_temp;
//Remove new dictionary references from legacy binary format
    HELP maximum_device_variables_help_temp;
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER;
}

/*****************************************************************************
 * This variable tracks the number of times a device's configuration has
 * changed. Its value increments each time a configuration change is made.
 *****************************************************************************
 */
VARIABLE config_change_counter
{
//Remove new dictionary references from legacy binary format
    LABEL Configuration_Change_Counter_temp;
//Remove new dictionary references from legacy binary format
    HELP configuration_change_counter_help_temp;
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (2);
}

/**********************************************************************
 * Notes on identity commands
 *
 * The VARIABLE manufacturer_id, combined with the VARIABLE
 * device_type, will uniquely identify a type of Field Device. The
 * combination of these two VARIABLEs will have only one unique
 * Device Description, though there may be revisions of the Device
 * Description.
 *
 * The VARIABLE manufacturer_id, combined with the VARIABLE
 * device_type, combined with the VARIABLE device_revision,
 * will identify the exact revision of the Device Description for
 * this type of Field Device.
 */
COMMAND read_unique_identifier
{
    NUMBER 0;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            IDENTIFY_REPLY_7
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS, no_command_specific_errors_temp;
    }
}

VARIABLE tag
{
//Remove new dictionary references from legacy binary format
    LABEL tag_temp;
//Remove new dictionary references from legacy binary format
    HELP tag_help_temp;
    CLASS DEVICE;
    TYPE PACKED_ASCII (8);
}

/* Command 11 is used inherently by host applications to identify devices by their tag.
   Even though this is declared as operation COMMAND, a corresponding METHOD is not included
   for this command, because it does not make sense to do this within the DD itself.
   A host application would have to identify a transmitter first, before connecting to it
   using a DD. */
COMMAND read_unique_identifier_with_tag
{
    NUMBER 11;
    OPERATION COMMAND;
    TRANSACTION
    {
        REQUEST
        {
            tag
        }
        REPLY
        {
            IDENTIFY_REPLY_7
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS,          no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
       38,  DATA_ENTRY_ERROR, Tag_mismatch_error_temp;
    }
}

VARIABLE longTag
{
//Remove new dictionary references from legacy binary format
    LABEL Long_Tag_temp;
//Remove new dictionary references from legacy binary format
    HELP long_tag_help_temp;
    CLASS DEVICE;
    TYPE ASCII (32);
}

/* Command 21 is used inherently by host applications to identify devices by their long tag.
   Even though this is declared as operation COMMAND, a corresponding METHOD is not included
   for this command, because it does not make sense to do this within the DD itself.
   A host application would have to identify a transmitter first, before connecting to it
   using a DD. */
COMMAND read_unique_identifier_with_long_tag
{
    NUMBER 21;
    OPERATION COMMAND;
    TRANSACTION
    {
        REQUEST
        {
            longTag
        }
        REPLY
        {
            IDENTIFY_REPLY_7
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS,          no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
       38,  DATA_ENTRY_ERROR, Tag_mismatch_error_temp;
    }
}

/**********************************************************************
 * Process data commands
 */

COMMAND read_pv
{
    NUMBER 1;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status,
            PV.DEVICE_VARIABLE.DIGITAL_UNITS, PV.DEVICE_VARIABLE.DIGITAL_VALUE
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS,      no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
        6,  MISC_ERROR,   xmtr_specific_command_error_temp;
//Remove new dictionary references from legacy binary format
        8,  MISC_WARNING, update_failure_temp;
//Remove new dictionary references from legacy binary format
        16, MODE_ERROR,   access_restricted_temp;
    }
}

COMMAND read_pv_current_and_percent_range
{
    NUMBER 2;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status,
            PV.DAQ.ANALOG_VALUE,
            PV.RANGING.PERCENT_RANGE
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS,      no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
        6,  MISC_ERROR,   xmtr_specific_command_error_temp;
//Remove new dictionary references from legacy binary format
        8,  MISC_WARNING, update_failure_temp;
//Remove new dictionary references from legacy binary format
        16, MODE_ERROR,   access_restricted_temp;
    }
}

COMMAND read_dynamic_variables_and_pv_current
{
    NUMBER 3;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status,
            PV.DAQ.ANALOG_VALUE,
            PV.DEVICE_VARIABLE.DIGITAL_UNITS, PV.DEVICE_VARIABLE.DIGITAL_VALUE,
            SV.DEVICE_VARIABLE.DIGITAL_UNITS, SV.DEVICE_VARIABLE.DIGITAL_VALUE,
            TV.DEVICE_VARIABLE.DIGITAL_UNITS, TV.DEVICE_VARIABLE.DIGITAL_VALUE,
            QV.DEVICE_VARIABLE.DIGITAL_UNITS, QV.DEVICE_VARIABLE.DIGITAL_VALUE
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS,      no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
        6,  MISC_ERROR,   xmtr_specific_command_error_temp;
//Remove new dictionary references from legacy binary format
        8,  MISC_WARNING, update_failure_temp;
//Remove new dictionary references from legacy binary format
        16, MODE_ERROR,   access_restricted_temp;
    }
}


VARIABLE device_variable_code_1
{
    CLASS LOCAL;
    TYPE INDEX deviceVariables;
}

VARIABLE device_variable_code_2
{
    CLASS LOCAL;
    TYPE INDEX deviceVariables;
}

VARIABLE device_variable_code_3
{
    CLASS LOCAL;
    TYPE INDEX deviceVariables;
}

VARIABLE device_variable_code_4
{
    CLASS LOCAL;
    TYPE INDEX deviceVariables;
}

VARIABLE device_variable_code_5
{
    CLASS LOCAL;
    TYPE INDEX deviceVariables;
}

VARIABLE device_variable_code_6
{
    CLASS LOCAL;
    TYPE INDEX deviceVariables;
}

VARIABLE device_variable_code_7
{
    CLASS LOCAL;
    TYPE INDEX deviceVariables;
}

VARIABLE device_variable_code_8
{
    CLASS LOCAL;
    TYPE INDEX deviceVariables;
}

#if __TOKVER__ >= 800
VARIABLE time_stamp
{
//Remove new dictionary references from legacy binary format
    LABEL time_stamp_temp;
//Remove new dictionary references from legacy binary format
    HELP time_stamp_help_temp;
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE TIME_VALUE;
}
#endif //__TOKVER__ >=  800

COMMAND read_device_variables_and_status
{
    NUMBER 9;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
            device_variable_code_1 (INFO,INDEX),
            device_variable_code_2 (INFO,INDEX),
            device_variable_code_3 (INFO,INDEX),
            device_variable_code_4 (INFO,INDEX)
#if __TOKVER__ >= 800
           ,device_variable_code_5 (INFO,INDEX),
            device_variable_code_6 (INFO,INDEX),
            device_variable_code_7 (INFO,INDEX),
            device_variable_code_8 (INFO,INDEX)
#endif //__TOKVER__ >=  800
        }
        REPLY
        {
            response_code, device_status,
            extended_fld_device_status,

            device_variable_code_1 (INFO,INDEX),
            deviceVariables[device_variable_code_1].CLASSIFICATION,
            deviceVariables[device_variable_code_1].DIGITAL_UNITS,
            deviceVariables[device_variable_code_1].DIGITAL_VALUE,
            deviceVariables[device_variable_code_1].DATA_QUALITY <0xC0>,
            deviceVariables[device_variable_code_1].LIMIT_STATUS <0x30>,
            deviceVariables[device_variable_code_1].DEVICE_FAMILY_STATUS <0x0F>,

            device_variable_code_2 (INFO,INDEX),
            deviceVariables[device_variable_code_2].CLASSIFICATION,
            deviceVariables[device_variable_code_2].DIGITAL_UNITS,
            deviceVariables[device_variable_code_2].DIGITAL_VALUE,
            deviceVariables[device_variable_code_2].DATA_QUALITY <0xC0>,
            deviceVariables[device_variable_code_2].LIMIT_STATUS <0x30>,
            deviceVariables[device_variable_code_2].DEVICE_FAMILY_STATUS <0x0F>,

            device_variable_code_3 (INFO,INDEX),
            deviceVariables[device_variable_code_3].CLASSIFICATION,
            deviceVariables[device_variable_code_3].DIGITAL_UNITS,
            deviceVariables[device_variable_code_3].DIGITAL_VALUE,
            deviceVariables[device_variable_code_3].DATA_QUALITY <0xC0>,
            deviceVariables[device_variable_code_3].LIMIT_STATUS <0x30>,
            deviceVariables[device_variable_code_3].DEVICE_FAMILY_STATUS <0x0F>,

            device_variable_code_4 (INFO,INDEX),
            deviceVariables[device_variable_code_4].CLASSIFICATION,
            deviceVariables[device_variable_code_4].DIGITAL_UNITS,
            deviceVariables[device_variable_code_4].DIGITAL_VALUE,
            deviceVariables[device_variable_code_4].DATA_QUALITY <0xC0>,
            deviceVariables[device_variable_code_4].LIMIT_STATUS <0x30>,
            deviceVariables[device_variable_code_4].DEVICE_FAMILY_STATUS <0x0F>
#if __TOKVER__ >= 800
           ,device_variable_code_5 (INFO,INDEX),
            deviceVariables[device_variable_code_5].CLASSIFICATION,
            deviceVariables[device_variable_code_5].DIGITAL_UNITS,
            deviceVariables[device_variable_code_5].DIGITAL_VALUE,
            deviceVariables[device_variable_code_5].DATA_QUALITY <0xC0>,
            deviceVariables[device_variable_code_5].LIMIT_STATUS <0x30>,
            deviceVariables[device_variable_code_5].DEVICE_FAMILY_STATUS <0x0F>,

            device_variable_code_6 (INFO,INDEX),
            deviceVariables[device_variable_code_6].CLASSIFICATION,
            deviceVariables[device_variable_code_6].DIGITAL_UNITS,
            deviceVariables[device_variable_code_6].DIGITAL_VALUE,
            deviceVariables[device_variable_code_6].DATA_QUALITY <0xC0>,
            deviceVariables[device_variable_code_6].LIMIT_STATUS <0x30>,
            deviceVariables[device_variable_code_6].DEVICE_FAMILY_STATUS <0x0F>,

            device_variable_code_7 (INFO,INDEX),
            deviceVariables[device_variable_code_7].CLASSIFICATION,
            deviceVariables[device_variable_code_7].DIGITAL_UNITS,
            deviceVariables[device_variable_code_7].DIGITAL_VALUE,
            deviceVariables[device_variable_code_7].DATA_QUALITY <0xC0>,
            deviceVariables[device_variable_code_7].LIMIT_STATUS <0x30>,
            deviceVariables[device_variable_code_7].DEVICE_FAMILY_STATUS <0x0F>,

            device_variable_code_8 (INFO,INDEX),
            deviceVariables[device_variable_code_8].CLASSIFICATION,
            deviceVariables[device_variable_code_8].DIGITAL_UNITS,
            deviceVariables[device_variable_code_8].DIGITAL_VALUE,
            deviceVariables[device_variable_code_8].DATA_QUALITY <0xC0>,
            deviceVariables[device_variable_code_8].LIMIT_STATUS <0x30>,
            deviceVariables[device_variable_code_8].DEVICE_FAMILY_STATUS <0x0F>,
            time_stamp
#endif //__TOKVER__ >=  800
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS,          no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
        2,  DATA_ENTRY_ERROR, invalid_selection_temp;
//Remove new dictionary references from legacy binary format
        5,  DATA_ENTRY_ERROR, too_few_data_bytes_recieved_temp;
//Remove new dictionary references from legacy binary format
        6,  MISC_ERROR,       xmtr_specific_command_error_temp;
//Remove new dictionary references from legacy binary format
        8,  MISC_WARNING,     update_failure_temp;
//Remove new dictionary references from legacy binary format
        14, MISC_WARNING,     dynamic_variables_returned_temp;
//Remove new dictionary references from legacy binary format
        16, MODE_ERROR,       access_restricted_temp;
//Remove new dictionary references from legacy binary format
        30, MISC_WARNING,     command_response_truncated_temp;
    }
}

/**********************************************************************
 * Polling address and loop current mode commands
 */

VARIABLE polling_address
{
//Remove new dictionary references from legacy binary format
    LABEL Polling_Address_temp;
//Remove new dictionary references from legacy binary format
    HELP poll_address_help_temp;
    CLASS HART;
    TYPE UNSIGNED_INTEGER
    {
        MAX_VALUE 63;
    }
    DEFAULT_VALUE 0;  // Support hosts that need it in their offline configuration
}

COMMAND write_polling_address
{
    NUMBER 6;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            polling_address, loop_current_mode
        }
        REPLY
        {
            response_code, device_status, polling_address, loop_current_mode
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS,          no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
        2,  DATA_ENTRY_ERROR, invalid_poll_address_selection_temp;
//Remove new dictionary references from legacy binary format
        5,  DATA_ENTRY_ERROR, too_few_data_bytes_recieved_temp;
//Remove new dictionary references from legacy binary format
        6,  MISC_ERROR,       xmtr_specific_command_error_temp;
//Remove new dictionary references from legacy binary format
        7,  MODE_ERROR,       in_write_protect_mode_temp;
//Remove new dictionary references from legacy binary format
        12, MODE_ERROR,       invalid_mode_selection_temp;
//Remove new dictionary references from legacy binary format
        16, MODE_ERROR,       access_restricted_temp;
//Remove new dictionary references from legacy binary format
        32, MODE_ERROR,       busy_temp;
    }
}

COMMAND read_loop_configuration
{
    NUMBER 7;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status, polling_address, loop_current_mode
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS,    no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
        16, MODE_ERROR, access_restricted_temp;
    }
}

COMMAND read_dynamic_variable_classification
{
    NUMBER 8;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status,
            PV.DEVICE_VARIABLE.CLASSIFICATION,
            SV.DEVICE_VARIABLE.CLASSIFICATION,
            TV.DEVICE_VARIABLE.CLASSIFICATION,
            QV.DEVICE_VARIABLE.CLASSIFICATION
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS,    no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
        16, MODE_ERROR, access_restricted_temp;
    }
}

COMMAND read_pv_sensor_info
{
    NUMBER 14;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status,
            PV.DEVICE_VARIABLE.SENSOR_SERIAL_NUMBER,
            PV.DEVICE_VARIABLE.CONFIG_UNITS,
            PV.DEVICE_VARIABLE.UPPER_SENSOR_LIMIT,
            PV.DEVICE_VARIABLE.LOWER_SENSOR_LIMIT,
            PV.DEVICE_VARIABLE.MINIMUM_SPAN
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0, SUCCESS,     no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
        16, MODE_ERROR, access_restricted_temp;
//Remove new dictionary references from legacy binary format
        32, MODE_ERROR, busy_temp;
    }
}

COMMAND read_pv_output_info
{
    NUMBER 15;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status,
            PV.DAQ.ALARM_CODE,
            PV.RANGING.TRANSFER_FUNCTION,
            PV.RANGING.RANGE_UNITS,
            PV.RANGING.UPPER_RANGE_VALUE,
            PV.RANGING.LOWER_RANGE_VALUE,
            PV.DEVICE_VARIABLE.DAMPING_VALUE,
            write_protect,
            250,
            PV.DAQ.ANALOG_CHANNEL_FLAGS
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS,    no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
        16, MODE_ERROR, access_restricted_temp;
//Remove new dictionary references from legacy binary format
        32, MODE_ERROR, busy_temp;
    }
}

VARIABLE message
{
//Remove new dictionary references from legacy binary format
    LABEL message_temp;
//Remove new dictionary references from legacy binary format
    HELP message_help_temp;
    CLASS DEVICE;
    TYPE PACKED_ASCII (32);
}

COMMAND read_message
{
    NUMBER 12;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status, message
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS,    no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
        16, MODE_ERROR, access_restricted_temp;
//Remove new dictionary references from legacy binary format
        32, MODE_ERROR, busy_temp;
    }
}

COMMAND write_message
{
    NUMBER 17;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            message
        }
        REPLY
        {
            response_code, device_status, message
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS,          no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
        5,  DATA_ENTRY_ERROR, too_few_data_bytes_recieved_temp;
//Remove new dictionary references from legacy binary format
        6,  MISC_ERROR,       xmtr_specific_command_error_temp;
//Remove new dictionary references from legacy binary format
        7,  MODE_ERROR,       in_write_protect_mode_temp;
//Remove new dictionary references from legacy binary format
        16, MODE_ERROR,       access_restricted_temp;
//Remove new dictionary references from legacy binary format
        32, MODE_ERROR,       busy_temp;
     }
}

VARIABLE descriptor
{
//Remove new dictionary references from legacy binary format
    LABEL descriptor_temp;
//Remove new dictionary references from legacy binary format
    HELP descriptor_help_temp;
    CLASS DEVICE;
    TYPE PACKED_ASCII (16);
}

VARIABLE date
{
//Remove new dictionary references from legacy binary format
    LABEL date_temp;
//Remove new dictionary references from legacy binary format
    HELP date_help_temp;
    CLASS DEVICE;
    TYPE DATE;
}

COMMAND read_tag_descriptor_date
{
    NUMBER 13;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status, tag, descriptor, date
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS,    no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
        16, MODE_ERROR, access_restricted_temp;
//Remove new dictionary references from legacy binary format
        32, MODE_ERROR, busy_temp;
    }
}

COMMAND write_tag_descriptor_date
{
    NUMBER 18;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            tag, descriptor, date
        }
        REPLY
        {
            response_code, device_status, tag, descriptor, date
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS,          no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
        5,  DATA_ENTRY_ERROR, too_few_data_bytes_recieved_temp;
//Remove new dictionary references from legacy binary format
        6,  MISC_ERROR,       xmtr_specific_command_error_temp;
//Remove new dictionary references from legacy binary format
        7,  MODE_ERROR,       in_write_protect_mode_temp;
//Remove new dictionary references from legacy binary format
        9,  DATA_ENTRY_ERROR, invalid_date_code_detected_temp;
//Remove new dictionary references from legacy binary format
        16, MODE_ERROR,       access_restricted_temp;
//Remove new dictionary references from legacy binary format
        32, MODE_ERROR,       busy_temp;
    }
}

VARIABLE final_assembly_number
{
//Remove new dictionary references from legacy binary format
    LABEL Final_Assembly_Number_temp;
//Remove new dictionary references from legacy binary format
    HELP final_assembly_number_help_temp;
    CLASS DEVICE;
    TYPE UNSIGNED_INTEGER (3)
    {
        MAX_VALUE 16777215;
        EDIT_FORMAT "8u" ;
    }
}

COMMAND read_final_assembly_number
{
    NUMBER 16;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status, final_assembly_number
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS,    no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
        16, MODE_ERROR, access_restricted_temp;
//Remove new dictionary references from legacy binary format
        32, MODE_ERROR, busy_temp;
    }
}

COMMAND write_final_assembly_number
{
    NUMBER 19;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            final_assembly_number
        }
        REPLY
        {
            response_code, device_status, final_assembly_number
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS,          no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
        5,  DATA_ENTRY_ERROR, too_few_data_bytes_recieved_temp;
//Remove new dictionary references from legacy binary format
        6,  MISC_ERROR,       xmtr_specific_command_error_temp;
//Remove new dictionary references from legacy binary format
        7,  MODE_ERROR,       in_write_protect_mode_temp;
//Remove new dictionary references from legacy binary format
        16, MODE_ERROR,       access_restricted_temp;
//Remove new dictionary references from legacy binary format
        32, MODE_ERROR,       busy_temp;
    }
}

COMMAND read_long_tag
{
    NUMBER 20;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status, longTag
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS,    no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
        16, MODE_ERROR, access_restricted_temp;
//Remove new dictionary references from legacy binary format
        32, MODE_ERROR, busy_temp;
    }
}

COMMAND write_long_tag
{
    NUMBER 22;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            longTag
        }
        REPLY
        {
            response_code, device_status, longTag
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS,          no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
        5,  DATA_ENTRY_ERROR, too_few_data_bytes_recieved_temp;
//Remove new dictionary references from legacy binary format
        6,  MISC_ERROR,       xmtr_specific_command_error_temp;
//Remove new dictionary references from legacy binary format
        7,  MODE_ERROR,       in_write_protect_mode_temp;
//Remove new dictionary references from legacy binary format
        16, MODE_ERROR,       access_restricted_temp;
//Remove new dictionary references from legacy binary format
        32, MODE_ERROR,       busy_temp;
//Remove new dictionary references from legacy binary format
        33, MODE_ERROR,       delayed_response_initiated_temp;
//Remove new dictionary references from legacy binary format
        34, MODE_ERROR,       delayed_response_running_temp;
//Remove new dictionary references from legacy binary format
        35, MODE_ERROR,       delayed_response_dead_temp;
//Remove new dictionary references from legacy binary format
        36, MODE_ERROR,       delayed_response_conflict_temp;
    }
}

/* Command 38 is used inherently by host applications to manage configuration changes.
   Even though this is declared as operation COMMAND, a corresponding METHOD is not included
   for this command, because it does not make sense for end users to interact
   with the configuration change flag. Users interaction with the flag could cause
   inconsistencies with the host application configuration database. */
COMMAND reset_configuration_change_flag
{
    NUMBER 38;
    OPERATION COMMAND;
    TRANSACTION
    {
        REQUEST
        {
            config_change_counter (INFO)
        }
        REPLY
        {
            response_code, device_status, config_change_counter (INFO)
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS,          no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
        5,  DATA_ENTRY_ERROR, too_few_data_bytes_recieved_temp;
//Remove new dictionary references from legacy binary format
        6,  MISC_ERROR,       xmtr_specific_command_error_temp;
//Remove new dictionary references from legacy binary format
        7,  MODE_ERROR,       in_write_protect_mode_temp;
//Remove new dictionary references from legacy binary format
        9,  MISC_ERROR,       configuration_change_counter_mismatch_temp;
//Remove new dictionary references from legacy binary format
        16, MODE_ERROR,       access_restricted_temp;
    }
}

VARIABLE device_specific_status_0
{
//Remove new dictionary references from legacy binary format
    LABEL Device_Specific_Status_0_temp;
//Remove new dictionary references from legacy binary format
    HELP field_device_status_0_help_temp;
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 0x01, dev_spec_stat1_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x02, dev_spec_stat2_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x04, dev_spec_stat3_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x08, dev_spec_stat4_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x10, dev_spec_stat5_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x20, dev_spec_stat6_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x40, dev_spec_stat7_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x80, dev_spec_stat8_temp, MISC }
    }
}

VARIABLE device_specific_status_1
{
//Remove new dictionary references from legacy binary format
    LABEL Device_Specific_Status_1_temp;
//Remove new dictionary references from legacy binary format
    HELP field_device_status_1_help_temp;
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 0x01, dev_spec_stat1_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x02, dev_spec_stat2_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x04, dev_spec_stat3_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x08, dev_spec_stat4_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x10, dev_spec_stat5_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x20, dev_spec_stat6_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x40, dev_spec_stat7_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x80, dev_spec_stat8_temp, MISC }
    }
}

VARIABLE device_specific_status_2
{
//Remove new dictionary references from legacy binary format
    LABEL Device_Specific_Status_2_temp;
//Remove new dictionary references from legacy binary format
    HELP field_device_status_2_help_temp;
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 0x01, dev_spec_stat1_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x02, dev_spec_stat2_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x04, dev_spec_stat3_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x08, dev_spec_stat4_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x10, dev_spec_stat5_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x20, dev_spec_stat6_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x40, dev_spec_stat7_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x80, dev_spec_stat8_temp, MISC }
    }
}

VARIABLE device_specific_status_3
{
//Remove new dictionary references from legacy binary format
    LABEL Device_Specific_Status_3_temp;
//Remove new dictionary references from legacy binary format
    HELP field_device_status_3_help_temp;
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 0x01, dev_spec_stat1_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x02, dev_spec_stat2_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x04, dev_spec_stat3_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x08, dev_spec_stat4_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x10, dev_spec_stat5_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x20, dev_spec_stat6_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x40, dev_spec_stat7_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x80, dev_spec_stat8_temp, MISC }
    }
}

VARIABLE device_specific_status_4
{
//Remove new dictionary references from legacy binary format
    LABEL Device_Specific_Status_4_temp;
//Remove new dictionary references from legacy binary format
    HELP field_device_status_4_help_temp;
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 0x01, dev_spec_stat1_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x02, dev_spec_stat2_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x04, dev_spec_stat3_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x08, dev_spec_stat4_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x10, dev_spec_stat5_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x20, dev_spec_stat6_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x40, dev_spec_stat7_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x80, dev_spec_stat8_temp, MISC }
    }
}

VARIABLE device_specific_status_5
{
//Remove new dictionary references from legacy binary format
    LABEL Device_Specific_Status_5_temp;
//Remove new dictionary references from legacy binary format
    HELP field_device_status_5_help_temp;
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 0x01, dev_spec_stat1_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x02, dev_spec_stat2_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x04, dev_spec_stat3_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x08, dev_spec_stat4_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x10, dev_spec_stat5_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x20, dev_spec_stat6_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x40, dev_spec_stat7_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x80, dev_spec_stat8_temp, MISC }
    }
}

VARIABLE device_specific_status_14
{
//Remove new dictionary references from legacy binary format
    LABEL Device_Specific_Status_14_temp;
//Remove new dictionary references from legacy binary format
    HELP field_device_status_14_help_temp;
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 0x01, dev_spec_stat1_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x02, dev_spec_stat2_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x04, dev_spec_stat3_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x08, dev_spec_stat4_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x10, dev_spec_stat5_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x20, dev_spec_stat6_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x40, dev_spec_stat7_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x80, dev_spec_stat8_temp, MISC }
    }
}

VARIABLE device_specific_status_15
{
//Remove new dictionary references from legacy binary format
    LABEL Device_Specific_Status_15_temp;
//Remove new dictionary references from legacy binary format
    HELP field_device_status_15_help_temp;
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 0x01, dev_spec_stat1_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x02, dev_spec_stat2_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x04, dev_spec_stat3_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x08, dev_spec_stat4_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x10, dev_spec_stat5_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x20, dev_spec_stat6_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x40, dev_spec_stat7_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x80, dev_spec_stat8_temp, MISC }
    }
}

VARIABLE device_specific_status_16
{
//Remove new dictionary references from legacy binary format
    LABEL Device_Specific_Status_16_temp;
//Remove new dictionary references from legacy binary format
    HELP field_device_status_16_help_temp;
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 0x01, dev_spec_stat1_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x02, dev_spec_stat2_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x04, dev_spec_stat3_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x08, dev_spec_stat4_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x10, dev_spec_stat5_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x20, dev_spec_stat6_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x40, dev_spec_stat7_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x80, dev_spec_stat8_temp, MISC }
    }
}

VARIABLE device_specific_status_17
{
//Remove new dictionary references from legacy binary format
    LABEL Device_Specific_Status_17_temp;
//Remove new dictionary references from legacy binary format
    HELP field_device_status_17_help_temp;
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 0x01, dev_spec_stat1_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x02, dev_spec_stat2_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x04, dev_spec_stat3_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x08, dev_spec_stat4_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x10, dev_spec_stat5_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x20, dev_spec_stat6_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x40, dev_spec_stat7_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x80, dev_spec_stat8_temp, MISC }
    }
}

VARIABLE device_specific_status_18
{
//Remove new dictionary references from legacy binary format
    LABEL Device_Specific_Status_18_temp;
//Remove new dictionary references from legacy binary format
    HELP field_device_status_18_help_temp;
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 0x01, dev_spec_stat1_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x02, dev_spec_stat2_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x04, dev_spec_stat3_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x08, dev_spec_stat4_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x10, dev_spec_stat5_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x20, dev_spec_stat6_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x40, dev_spec_stat7_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x80, dev_spec_stat8_temp, MISC }
    }
}

VARIABLE device_specific_status_19
{
//Remove new dictionary references from legacy binary format
    LABEL Device_Specific_Status_19_temp;
//Remove new dictionary references from legacy binary format
    HELP field_device_status_19_help_temp;
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 0x01, dev_spec_stat1_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x02, dev_spec_stat2_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x04, dev_spec_stat3_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x08, dev_spec_stat4_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x10, dev_spec_stat5_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x20, dev_spec_stat6_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x40, dev_spec_stat7_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x80, dev_spec_stat8_temp, MISC }
    }
}

VARIABLE device_specific_status_20
{
//Remove new dictionary references from legacy binary format
    LABEL Device_Specific_Status_20_temp;
//Remove new dictionary references from legacy binary format
    HELP field_device_status_20_help_temp;
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 0x01, dev_spec_stat1_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x02, dev_spec_stat2_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x04, dev_spec_stat3_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x08, dev_spec_stat4_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x10, dev_spec_stat5_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x20, dev_spec_stat6_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x40, dev_spec_stat7_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x80, dev_spec_stat8_temp, MISC }
    }
}

VARIABLE device_specific_status_21
{
//Remove new dictionary references from legacy binary format
    LABEL Device_Specific_Status_21_temp;
//Remove new dictionary references from legacy binary format
    HELP field_device_status_21_help_temp;
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 0x01, dev_spec_stat1_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x02, dev_spec_stat2_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x04, dev_spec_stat3_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x08, dev_spec_stat4_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x10, dev_spec_stat5_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x20, dev_spec_stat6_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x40, dev_spec_stat7_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x80, dev_spec_stat8_temp, MISC }
    }
}

VARIABLE device_specific_status_22
{
//Remove new dictionary references from legacy binary format
    LABEL Device_Specific_Status_22_temp;
//Remove new dictionary references from legacy binary format
    HELP field_device_status_22_help_temp;
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 0x01, dev_spec_stat1_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x02, dev_spec_stat2_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x04, dev_spec_stat3_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x08, dev_spec_stat4_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x10, dev_spec_stat5_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x20, dev_spec_stat6_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x40, dev_spec_stat7_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x80, dev_spec_stat8_temp, MISC }
    }
}

VARIABLE device_specific_status_23
{
//Remove new dictionary references from legacy binary format
    LABEL Device_Specific_Status_23_temp;
//Remove new dictionary references from legacy binary format
    HELP field_device_status_23_help_temp;
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 0x01, dev_spec_stat1_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x02, dev_spec_stat2_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x04, dev_spec_stat3_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x08, dev_spec_stat4_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x10, dev_spec_stat5_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x20, dev_spec_stat6_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x40, dev_spec_stat7_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x80, dev_spec_stat8_temp, MISC }
    }
}

VARIABLE device_specific_status_24
{
//Remove new dictionary references from legacy binary format
    LABEL Device_Specific_Status_24_temp;
//Remove new dictionary references from legacy binary format
    HELP field_device_status_24_help_temp;
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 0x01, dev_spec_stat1_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x02, dev_spec_stat2_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x04, dev_spec_stat3_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x08, dev_spec_stat4_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x10, dev_spec_stat5_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x20, dev_spec_stat6_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x40, dev_spec_stat7_temp, MISC },
//Remove new dictionary references from legacy binary format
        { 0x80, dev_spec_stat8_temp, MISC }
    }
}

/*****************************************************************************
 * Command 48
 *
 * This is a generic definition of command 48 and most implementations
 * truncate the command when IMPORTING
 *
 * NOTE 1 - the VARIABLE's device_specific_statusXX are normally REDEFINE'd by the
 * device DD
 *
 * NOTE 2 - All devices must support at least bytes 0-8 including extended_fld_device_status,
 * operatingMode (which must be 0x00) and standardized_status_0.
 *
 * 2 transactions are defined in order to allow a read of command 48 information in transaction 0,
 * so the host application can use the information in the request of transaction 1 in order to
 * acknowledge the more status available flag.
 */
COMMAND read_additional_device_status
{
    NUMBER 48;
    OPERATION READ;
    TRANSACTION 0
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status,
            device_specific_status_0, device_specific_status_1, device_specific_status_2,
            device_specific_status_3, device_specific_status_4, device_specific_status_5,

            extended_fld_device_status, 0x00,

            standardized_status_0, standardized_status_1, analog_channel_saturated1,
            standardized_status_2, standardized_status_3, analog_channel_fixed1,

            device_specific_status_14, device_specific_status_15, device_specific_status_16,
            device_specific_status_17, device_specific_status_18, device_specific_status_19,
            device_specific_status_20, device_specific_status_21, device_specific_status_22,
            device_specific_status_23, device_specific_status_24
        }
    }
    TRANSACTION 1
    {
        REQUEST
        {
            device_specific_status_0 (INFO), device_specific_status_1 (INFO), device_specific_status_2 (INFO),
            device_specific_status_3 (INFO), device_specific_status_4 (INFO), device_specific_status_5 (INFO),

            extended_fld_device_status (INFO), 0x00,

            standardized_status_0 (INFO), standardized_status_1 (INFO), analog_channel_saturated1 (INFO),
            standardized_status_2 (INFO), standardized_status_3 (INFO), analog_channel_fixed1 (INFO),

            device_specific_status_14 (INFO), device_specific_status_15 (INFO), device_specific_status_16 (INFO),
            device_specific_status_17 (INFO), device_specific_status_18 (INFO), device_specific_status_19 (INFO),
            device_specific_status_20 (INFO), device_specific_status_21 (INFO), device_specific_status_22 (INFO),
            device_specific_status_23 (INFO), device_specific_status_24 (INFO)
        }
        REPLY
        {
            response_code, device_status,
            device_specific_status_0 (INFO), device_specific_status_1 (INFO), device_specific_status_2 (INFO),
            device_specific_status_3 (INFO), device_specific_status_4 (INFO), device_specific_status_5 (INFO),

            extended_fld_device_status (INFO), 0x00,

            standardized_status_0 (INFO), standardized_status_1 (INFO), analog_channel_saturated1 (INFO),
            standardized_status_2 (INFO), standardized_status_3 (INFO), analog_channel_fixed1 (INFO),

            device_specific_status_14 (INFO), device_specific_status_15 (INFO), device_specific_status_16 (INFO),
            device_specific_status_17 (INFO), device_specific_status_18 (INFO), device_specific_status_19 (INFO),
            device_specific_status_20 (INFO), device_specific_status_21 (INFO), device_specific_status_22 (INFO),
            device_specific_status_23 (INFO), device_specific_status_24 (INFO)
        }
    }
    RESPONSE_CODES
    {
//Remove new dictionary references from legacy binary format
        0,  SUCCESS,          no_command_specific_errors_temp;
//Remove new dictionary references from legacy binary format
        5,  DATA_ENTRY_ERROR, too_few_data_bytes_recieved_temp;
//Remove new dictionary references from legacy binary format
        6,  MISC_ERROR,       xmtr_specific_command_error_temp;
//Remove new dictionary references from legacy binary format
        8,  MISC_WARNING,     update_in_progress_temp;
//Remove new dictionary references from legacy binary format
        14, MISC_WARNING,     status_bytes_mismatch_temp;
//Remove new dictionary references from legacy binary format
        16, MODE_ERROR,       access_restricted_temp;
    }
}


/*****************************************************************************
 * Copies of device specific status used for event notifications.
 *
 * These are defined here to make sure they stay associated with the
 * base variables that they are created from.
 *
 * DDs only need import these if their device supports event notifications, 
 * and the DD imports common practice commands 115, 116, and/or 119
 *
 */
device_specific_status_0_mask  LIKE VARIABLE device_specific_status_0
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_0_mask_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_0_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_1_mask  LIKE VARIABLE device_specific_status_1
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_1_mask_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_1_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_2_mask  LIKE VARIABLE device_specific_status_2
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_2_mask_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_2_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_3_mask  LIKE VARIABLE device_specific_status_3
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_3_mask_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_3_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_4_mask  LIKE VARIABLE device_specific_status_4
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_4_mask_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_4_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_5_mask  LIKE VARIABLE device_specific_status_5
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_5_mask_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_5_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_14_mask LIKE VARIABLE device_specific_status_14
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_14_mask_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_14_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_15_mask LIKE VARIABLE device_specific_status_15
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_15_mask_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_15_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_16_mask LIKE VARIABLE device_specific_status_16
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_16_mask_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_16_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_17_mask LIKE VARIABLE device_specific_status_17
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_17_mask_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_17_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_18_mask LIKE VARIABLE device_specific_status_18
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_18_mask_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_18_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_19_mask LIKE VARIABLE device_specific_status_19
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_19_mask_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_19_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_20_mask LIKE VARIABLE device_specific_status_20
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_20_mask_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_20_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_21_mask LIKE VARIABLE device_specific_status_21
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_21_mask_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_21_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_22_mask LIKE VARIABLE device_specific_status_22
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_22_mask_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_22_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_23_mask LIKE VARIABLE device_specific_status_23
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_23_mask_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_23_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_24_mask LIKE VARIABLE device_specific_status_24
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_24_mask_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_24_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_0_latched_value  LIKE VARIABLE device_specific_status_0
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_0_latched_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_0_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_1_latched_value  LIKE VARIABLE device_specific_status_1
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_1_latched_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_1_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_2_latched_value  LIKE VARIABLE device_specific_status_2
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_2_latched_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_2_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_3_latched_value  LIKE VARIABLE device_specific_status_3
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_3_latched_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_3_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_4_latched_value  LIKE VARIABLE device_specific_status_4
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_4_latched_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_4_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_5_latched_value  LIKE VARIABLE device_specific_status_5
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_5_latched_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_5_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_14_latched_value LIKE VARIABLE device_specific_status_14
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_14_latched_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_14_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_15_latched_value LIKE VARIABLE device_specific_status_15
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_15_latched_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_15_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_16_latched_value LIKE VARIABLE device_specific_status_16
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_16_latched_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_16_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_17_latched_value LIKE VARIABLE device_specific_status_17
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_17_latched_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_17_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_18_latched_value LIKE VARIABLE device_specific_status_18
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_18_latched_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_18_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_19_latched_value LIKE VARIABLE device_specific_status_19
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_19_latched_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_19_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_20_latched_value LIKE VARIABLE device_specific_status_20
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_20_latched_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_20_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_21_latched_value LIKE VARIABLE device_specific_status_21
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_21_latched_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_21_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_22_latched_value LIKE VARIABLE device_specific_status_22
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_22_latched_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_22_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_23_latched_value LIKE VARIABLE device_specific_status_23
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_23_latched_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_23_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_24_latched_value LIKE VARIABLE device_specific_status_24
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_24_latched_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_24_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

config_change_counter_latched_value LIKE VARIABLE config_change_counter
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL configuration_change_counter_latched_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  configuration_change_counter_latched_help_temp;
    REDEFINE CLASS DEVICE;
    REDEFINE HANDLING READ;
}

device_specific_status_0_mask_1  LIKE VARIABLE device_specific_status_0  // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_0_mask_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_0_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_1_mask_1  LIKE VARIABLE device_specific_status_1 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_1_mask_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_1_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_2_mask_1  LIKE VARIABLE device_specific_status_2  // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_2_mask_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_2_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_3_mask_1  LIKE VARIABLE device_specific_status_3 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_3_mask_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_3_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_4_mask_1  LIKE VARIABLE device_specific_status_4 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_4_mask_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_4_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_5_mask_1  LIKE VARIABLE device_specific_status_5 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_5_mask_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_5_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}


device_specific_status_14_mask_1 LIKE VARIABLE device_specific_status_14 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_14_mask_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_14_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_15_mask_1 LIKE VARIABLE device_specific_status_15 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_15_mask_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_15_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_16_mask_1 LIKE VARIABLE device_specific_status_16 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_16_mask_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_16_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_17_mask_1 LIKE VARIABLE device_specific_status_17 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_17_mask_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_17_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_18_mask_1 LIKE VARIABLE device_specific_status_18 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_18_mask_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_18_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_19_mask_1 LIKE VARIABLE device_specific_status_19 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_19_mask_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_19_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}


device_specific_status_20_mask_1 LIKE VARIABLE device_specific_status_20 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_20_mask_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_20_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_21_mask_1 LIKE VARIABLE device_specific_status_21 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_21_mask_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_21_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}


device_specific_status_22_mask_1 LIKE VARIABLE device_specific_status_22 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_22_mask_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_22_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_23_mask_1 LIKE VARIABLE device_specific_status_23 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_23_mask_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_23_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_24_mask_1 LIKE VARIABLE device_specific_status_24 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_24_mask_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_24_mask_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ & WRITE;
}

device_specific_status_0_latched_value_1  LIKE VARIABLE device_specific_status_0 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_0_latched_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_0_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_1_latched_value_1  LIKE VARIABLE device_specific_status_1 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_1_latched_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_1_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_2_latched_value_1  LIKE VARIABLE device_specific_status_2 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_2_latched_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_2_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_3_latched_value_1  LIKE VARIABLE device_specific_status_3 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_3_latched_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_3_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_4_latched_value_1  LIKE VARIABLE device_specific_status_4 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_4_latched_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_4_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_5_latched_value_1  LIKE VARIABLE device_specific_status_5 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_5_latched_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_5_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_14_latched_value_1 LIKE VARIABLE device_specific_status_14 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_14_latched_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_14_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_15_latched_value_1 LIKE VARIABLE device_specific_status_15 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_15_latched_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_15_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_16_latched_value_1 LIKE VARIABLE device_specific_status_16 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_16_latched_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_16_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_17_latched_value_1 LIKE VARIABLE device_specific_status_17 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_17_latched_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_17_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_18_latched_value_1 LIKE VARIABLE device_specific_status_18 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_18_latched_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_18_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_19_latched_value_1 LIKE VARIABLE device_specific_status_19 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_19_latched_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_19_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_20_latched_value_1 LIKE VARIABLE device_specific_status_20 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_20_latched_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_20_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_21_latched_value_1 LIKE VARIABLE device_specific_status_21 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_21_latched_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_21_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_22_latched_value_1 LIKE VARIABLE device_specific_status_22 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_22_latched_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_22_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_23_latched_value_1 LIKE VARIABLE device_specific_status_23 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_23_latched_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_23_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

device_specific_status_24_latched_value_1 LIKE VARIABLE device_specific_status_24 // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL device_specific_status_24_latched_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  device_specific_status_24_latched_help_temp;
    REDEFINE CLASS DEVICE & DIAGNOSTIC;
    REDEFINE HANDLING READ;
}

config_change_counter_latched_value_1 LIKE VARIABLE config_change_counter // 2nd Event
{
//Remove new dictionary references from legacy binary format
    REDEFINE LABEL configuration_change_counter_latched_event_2_temp;
//Remove new dictionary references from legacy binary format
    REDEFINE HELP  configuration_change_counter_latched_help_temp;
    REDEFINE CLASS DEVICE;
    REDEFINE HANDLING READ;
}
